@@ -6,20 +6,22 @@ use DBI;
 
 =head1 NAME
 
-  Bio::DOOP::DBSQL - MySQL control object
+Bio::DOOP::DBSQL - MySQL control object
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
   $db  = Bio::DOOP::DBSQL->connect("user","pass","database","localhost");
+
   $res = $db->query("SELECT * FROM sequence LIMIT 10");
+
   foreach (@$res) {
      @fields = @{$_};
      print "@fields\n";
@@ -27,25 +29,25 @@ our $VERSION = '0.05';
 
 =head1 DESCRIPTION
 
-  This object provides low level access to the MySQL database. In most
-  cases you do not need it, because the DOOP API handles the database
-  queries. Still, if you need some special query and the DOOP 
-  API can't help you, use the query method to access the database.
+This object provides low level access to the MySQL database. In most
+cases you do not need it, because the DOOP API handles the database
+queries. Still, if you need some special query and the DOOP 
+API can't help you, use the query method to access the database.
 
 =head1 AUTHORS
 
-  Tibor Nagy, Godollo, Hungary and Endre Sebestyen, Martonvasar, Hungary
+Tibor Nagy, Godollo, Hungary and Endre Sebestyen, Martonvasar, Hungary
 
 =head1 METHODS
 
 =head2 connect
 
-  $db = Bio::DOOP::DBSQL->connect("user","pass","database","localhost");
+You can connect to the database with this method. The arguments are the 
+following : username, password, database name, host. The return value
+is a Bio::DOOP::DBSQL object. You must use this object in the arguments
+of other objects.
 
-  You can connect to the database with this method. The arguments are the 
-  following : username, password, database name, host. The return value
-  is a Bio::DOOP::DBSQL object. You must use this object in the argument
-  of other objects.
+  $db = Bio::DOOP::DBSQL->connect("user","pass","database","localhost");
 
 =cut
 
@@ -68,11 +70,12 @@ sub connect {
 
 =head2 query
 
-  $db->query("SELECT COUNT(*) FROM Cluster;");
+You can run special SQL statements on the database. In this example we count
+the number of clusters.
 
-  You can run special SQL statements on the database. In this example we count
-  the number of clusters.
-  Returns an arrayref of the results.
+Returns an arrayref with the results of the MySQL query.
+
+  $db->query("SELECT COUNT(*) FROM cluster;");
 
 =cut
 
